@@ -1,6 +1,6 @@
 package Math::3Space;
-$Math::3Space::VERSION = '0.001';
-# VERSION
+
+our $VERSION = '0.002'; # VERSION
 # ABSTRACT: 3D Coordinate math with an intuitive cross-space mapping API
 
 use strict;
@@ -10,9 +10,30 @@ use Carp;
 require XSLoader;
 XSLoader::load('Math::3Space', $Math::3Space::VERSION);
 
+
+{ package Math::3Space::Exports;
+	use Exporter::Extensible -exporter_setup => 1;
+	*vec3= *Math::3Space::Vector::vec3;
+	*space= *Math::3Space::space;
+	export 'vec3', 'space';
+}
+sub import { shift; Math::3Space::Exports->import_into(scalar(caller), @_) }
+
+sub parent { $_[0]{parent} }
+
+require Math::3Space::Vector;
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Math::3Space - 3D Coordinate math with an intuitive cross-space mapping API
+
 =head1 SYNOPSIS
 
   use Math::3Space 'vec3', 'space';
@@ -69,23 +90,6 @@ without thinking about the details.
 The coordiante spaces can be exported as 4x4 matrices for use with OpenGL or other common 3D
 systems.
 
-=cut
-
-{ package Math::3Space::Exports;
-	use Exporter::Extensible -exporter_setup => 1;
-	*vec3= *Math::3Space::Vector::vec3;
-	*space= *Math::3Space::space;
-	export 'vec3', 'space';
-}
-sub import { shift; Math::3Space::Exports->import_into(scalar(caller), @_) }
-
-sub parent { $_[0]{parent} }
-
-require Math::3Space::Vector;
-1;
-
-__END__
-
 =head1 CONSTRUCTOR
 
 =head2 space
@@ -311,5 +315,19 @@ Get an OpenGL-compatible 16-element array representing a 4x4 matrix that would p
 projection as this space.  This can either be returned as 16 perl floats, or written into a
 packed buffer of 16 doubles.
 
-=cut
+=head1 AUTHOR
 
+Michael Conrad <mike@nrdvana.net>
+
+=head1 VERSION
+
+version 0.002
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Michael Conrad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
