@@ -1,6 +1,6 @@
 package Math::3Space::Vector;
-$Math::3Space::Vector::VERSION = '0.001';
-# VERSION
+
+our $VERSION = '0.002'; # VERSION
 # ABSTRACT: Object wrapping a buffer of three doubles
 
 use Exporter 'import';
@@ -10,8 +10,17 @@ our @EXPORT_OK= qw( vec3 );
 require Math::3Space;
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Math::3Space::Vector - Object wrapping a buffer of three doubles
+
 =head1 SYNOPSIS
 
   use Math::3Space::Vector 'vec3';
@@ -125,5 +134,19 @@ Dot product with another vector.
 Return a new vector which is the cross product C<< A x B >>, or if called with 2 parameters
 assign the cross product to the object itself.
 
-=cut
+=head1 AUTHOR
 
+Michael Conrad <mike@nrdvana.net>
+
+=head1 VERSION
+
+version 0.002
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by Michael Conrad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
